==> docusign-esign-java-2.1.0-sources.jar: com/docusign/esign/model/CurrencyPlanPrice.java <==
package com.docusign.esign.model;

import java.util.Objects;
import com.docusign.esign.model.CreditCardTypes;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonValue;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;





@javax.annotation.Generated(value = "class io.swagger.codegen.languages.JavaClientCodegen", date = "2017-03-06T16:42:36.211-08:00")
public class CurrencyPlanPrice   {
  
  private String currencyCode = null;
  private String currencySymbol = null;
  private String perSeatPrice = null;
  private CreditCardTypes supportedCardTypes = null;
  private String supportIncidentFee = null;
  private String supportPlanFee = null;

  
  /**
   * Specifies the ISO currency code for the account.
   **/
  
  @ApiModelProperty(value = "Specifies the ISO currency code for the account.")
  @JsonProperty("currencyCode")
  public String getCurrencyCode() {
    return currencyCode;
  }
  public void setCurrencyCode(String currencyCode) {
    this.currencyCode = currencyCode;
  }

  
  /**
   * Specifies the currency symbol for the account.
   **/
  
  @ApiModelProperty(value = "Specifies the currency symbol for the account.")
  @JsonProperty("currencySymbol")
  public String getCurrencySymbol() {
    return currencySymbol;
  }
  public void setCurrencySymbol(String currencySymbol) {
    this.currencySymbol = currencySymbol;
  }

  
  /**
   * 
   **/
  
  @ApiModelProperty(value = "")
  @JsonProperty("perSeatPrice")
  public String getPerSeatPrice() {
    return perSeatPrice;
  }
  public void setPerSeatPrice(String perSeatPrice) {
    this.perSeatPrice = perSeatPrice;
  }

  
  /**
   **/
  
  @ApiModelProperty(value = "")
  @JsonProperty("supportedCardTypes")
  public CreditCardTypes getSupportedCardTypes() {
    return supportedCardTypes;
  }
  public void setSupportedCardTypes(CreditCardTypes supportedCardTypes) {
    this.supportedCardTypes = supportedCardTypes;
  }

  
  /**
   * The support incident fee charged for each support incident.
   **/
  
  @ApiModelProperty(value = "The support incident fee charged for each support incident.")
  @JsonProperty("supportIncidentFee")
  public String getSupportIncidentFee() {
    return supportIncidentFee;
  }
  public void setSupportIncidentFee(String supportIncidentFee) {
    this.supportIncidentFee = supportIncidentFee;
  }

  
  /**
   * The support plan fee charged for this plan.
   **/
  
  @ApiModelProperty(value = "The support plan fee charged for this plan.")
  @JsonProperty("supportPlanFee")
  public String getSupportPlanFee() {
    return supportPlanFee;
  }
  public void setSupportPlanFee(String supportPlanFee) {
    this.supportPlanFee = supportPlanFee;
  }

  

  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    CurrencyPlanPrice currencyPlanPrice = (CurrencyPlanPrice) o;

    return true && Objects.equals(currencyCode, currencyPlanPrice.currencyCode) &&
        Objects.equals(currencySymbol, currencyPlanPrice.currencySymbol) &&
        Objects.equals(perSeatPrice, currencyPlanPrice.perSeatPrice) &&
        Objects.equals(supportedCardTypes, currencyPlanPrice.supportedCardTypes) &&
        Objects.equals(supportIncidentFee, currencyPlanPrice.supportIncidentFee) &&
        Objects.equals(supportPlanFee, currencyPlanPrice.supportPlanFee)
    ;
  }

  @Override
  public int hashCode() {
    return Objects.hash(currencyCode, currencySymbol, perSeatPrice, supportedCardTypes, supportIncidentFee, supportPlanFee);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class CurrencyPlanPrice {\n");
    
    if (currencyCode != null)
      sb.append("    currencyCode: ").append(toIndentedString(currencyCode)).append("\n");
    if (currencySymbol != null)
      sb.append("    currencySymbol: ").append(toIndentedString(currencySymbol)).append("\n");
    if (perSeatPrice != null)
      sb.append("    perSeatPrice: ").append(toIndentedString(perSeatPrice)).append("\n");
    if (supportedCardTypes != null)
      sb.append("    supportedCardTypes: ").append(toIndentedString(supportedCardTypes)).append("\n");
    if (supportIncidentFee != null)
      sb.append("    supportIncidentFee: ").append(toIndentedString(supportIncidentFee)).append("\n");
    if (supportPlanFee != null)
      sb.append("    supportPlanFee: ").append(toIndentedString(supportPlanFee)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}

==> docusign-esign-java-3.12.0-sources.jar: com/docusign/esign/model/CurrencyPlanPrice.java <==
package com.docusign.esign.model;

import java.util.Objects;
import java.util.Arrays;
import com.docusign.esign.model.CreditCardTypes;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

/**
 * CurrencyPlanPrice
 */

public class CurrencyPlanPrice {
  @JsonProperty("currencyCode")
  private String currencyCode = null;

  @JsonProperty("currencySymbol")
  private String currencySymbol = null;

  @JsonProperty("perSeatPrice")
  private String perSeatPrice = null;

  @JsonProperty("supportedCardTypes")
  private CreditCardTypes supportedCardTypes = null;

  @JsonProperty("supportIncidentFee")
  private String supportIncidentFee = null;

  @JsonProperty("supportPlanFee")
  private String supportPlanFee = null;

  public CurrencyPlanPrice currencyCode(String currencyCode) {
    this.currencyCode = currencyCode;
    return this;
  }

   /**
   * Specifies the ISO currency code for the account.
   * @return currencyCode
  **/
  @ApiModelProperty(value = "Specifies the ISO currency code for the account.")
  public String getCurrencyCode() {
    return currencyCode;
  }

  public void setCurrencyCode(String currencyCode) {
    this.currencyCode = currencyCode;
  }

  public CurrencyPlanPrice currencySymbol(String currencySymbol) {
    this.currencySymbol = currencySymbol;
    return this;
  }

   /**
   * Specifies the currency symbol for the account.
   * @return currencySymbol
  **/
  @ApiModelProperty(value = "Specifies the currency symbol for the account.")
  public String getCurrencySymbol() {
    return currencySymbol;
  }

  public void setCurrencySymbol(String currencySymbol) {
    this.currencySymbol = currencySymbol;
  }

  public CurrencyPlanPrice perSeatPrice(String perSeatPrice) {
    this.perSeatPrice = perSeatPrice;
    return this;
  }

   /**
   * 
   * @return perSeatPrice
  **/
  @ApiModelProperty(value = "")
  public String getPerSeatPrice() {
    return perSeatPrice;
  }

  public void setPerSeatPrice(String perSeatPrice) {
    this.perSeatPrice = perSeatPrice;
  }

  public CurrencyPlanPrice supportedCardTypes(CreditCardTypes supportedCardTypes) {
    this.supportedCardTypes = supportedCardTypes;
    return this;
  }

   /**
   * Get supportedCardTypes
   * @return supportedCardTypes
  **/
  @ApiModelProperty(value = "")
  public CreditCardTypes getSupportedCardTypes() {
    return supportedCardTypes;
  }

  public void setSupportedCardTypes(CreditCardTypes supportedCardTypes) {
    this.supportedCardTypes = supportedCardTypes;
  }

  public CurrencyPlanPrice supportIncidentFee(String supportIncidentFee) {
    this.supportIncidentFee = supportIncidentFee;
    return this;
  }

   /**
   * The support incident fee charged for each support incident.
   * @return supportIncidentFee
  **/
  @ApiModelProperty(value = "The support incident fee charged for each support incident.")
  public String getSupportIncidentFee() {
    return supportIncidentFee;
  }

  public void setSupportIncidentFee(String supportIncidentFee) {
    this.supportIncidentFee = supportIncidentFee;
  }

  public CurrencyPlanPrice supportPlanFee(String supportPlanFee) {
    this.supportPlanFee = supportPlanFee;
    return this;
  }

   /**
   * The support plan fee charged for this plan.
   * @return supportPlanFee
  **/
  @ApiModelProperty(value = "The support plan fee charged for this plan.")
  public String getSupportPlanFee() {
    return supportPlanFee;
  }

  public void setSupportPlanFee(String supportPlanFee) {
    this.supportPlanFee = supportPlanFee;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    CurrencyPlanPrice currencyPlanPrice = (CurrencyPlanPrice) o;
    return Objects.equals(this.currencyCode, currencyPlanPrice.currencyCode) &&
        Objects.equals(this.currencySymbol, currencyPlanPrice.currencySymbol) &&
        Objects.equals(this.perSeatPrice, currencyPlanPrice.perSeatPrice) &&
        Objects.equals(this.supportedCardTypes, currencyPlanPrice.supportedCardTypes) &&
        Objects.equals(this.supportIncidentFee, currencyPlanPrice.supportIncidentFee) &&
        Objects.equals(this.supportPlanFee, currencyPlanPrice.supportPlanFee);
  }

  @Override
  public int hashCode() {
    return Objects.hash(currencyCode, currencySymbol, perSeatPrice, supportedCardTypes, supportIncidentFee, supportPlanFee);
  }


  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class CurrencyPlanPrice {\n");
    
    sb.append("    currencyCode: ").append(toIndentedString(currencyCode)).append("\n");
    sb.append("    currencySymbol: ").append(toIndentedString(currencySymbol)).append("\n");
    sb.append("    perSeatPrice: ").append(toIndentedString(perSeatPrice)).append("\n");
    sb.append("    supportedCardTypes: ").append(toIndentedString(supportedCardTypes)).append("\n");
    sb.append("    supportIncidentFee: ").append(toIndentedString(supportIncidentFee)).append("\n");
    sb.append("    supportPlanFee: ").append(toIndentedString(supportPlanFee)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }

}
